A Circuits.UART.Framing implementation for handling framing of data exchanged with the Gecko bootloader during over-the-wire firmware updates.
A Circuits.UART.Framing implementation for handling framing of data exchanged with the Gecko bootloader during over-the-wire firmware updates.