Grizzly.Indicator (grizzly v9.1.0)

Copy Markdown View Source

Indicator handling for Grizzly when an indicator event is triggered

See Grizzly.Supervisor for configuring the dispatcher that Grizzly should use during runtime.

Summary

Types

dispatcher()

@type dispatcher() :: (event() -> :ok)

event()

@type event() :: :on | :off

Functions

handle_event(event, env, dispatcher)

@spec handle_event([String.t()], %{required(String.t()) => String.t()}, dispatcher()) ::
  :ok

Handles an event from BEAMNotify