Grizzly.ZWave (grizzly v9.1.0)

Copy Markdown View Source

Module for Z-Wave protocol specific functionality and information

Summary

Types

The volume at which a tone is played.

Types

endpoint_id()

@type endpoint_id() :: 0..127

node_id()

@type node_id() :: non_neg_integer()

seq_number()

@type seq_number() :: non_neg_integer()

sound_switch_volume()

@type sound_switch_volume() :: 0..100 | 255

The volume at which a tone is played.

Values

  • 0 - Indicates an off/mute volume setting.
  • 1..100 - Indicates the actual volume setting from 1% to 100%.
  • 255 - Restore the most recent non-zero volume setting. This value MUST be ignored if the current volume is not zero. This value MAY be used to set the default tone without modifying the volume setting.

Functions

crc16_aug_ccitt(data)

@spec crc16_aug_ccitt(binary() | [byte()]) :: 0..65535

CRC-16/AUG-CCITT

from_binary(binary)

@spec from_binary(binary()) ::
  {:ok, Grizzly.ZWave.Command.t()} | {:error, Grizzly.ZWave.DecodeError.t()}

to_binary(command)

@spec to_binary(Grizzly.ZWave.Command.t()) :: binary()