Grizzly.ZWave.CommandClasses.Indicator (grizzly v9.1.0)

Copy Markdown View Source

"Indicator" Command Class

The Indicator Command Class is used to help end users to monitor the operation or condition of the application provided by a supporting node.

Summary

Types

indicator_id()

@type indicator_id() ::
  byte()
  | :armed
  | :disarmed
  | :ready
  | :fault
  | :busy
  | :enter_id
  | :enter_pin
  | :code_accepted
  | :armed_stay
  | :armed_away
  | :alarming
  | :alarming_burglar
  | :alarming_smoke_fire
  | :alarming_co
  | :bypass_challenger
  | :entry_delay
  | :alarming_medical
  | :alarming_freeze_warning
  | :alarming_water_leak
  | :alarming_panic
  | :zone_1_armed
  | :zone_2_armed
  | :zone_3_armed
  | :zone_4_armed
  | :zone_5_armed
  | :zone_6_armed
  | :zone_7_armed
  | :zone_8_armed
  | :lcd_backlight
  | :button_1
  | :button_2
  | :button_3
  | :button_4
  | :button_5
  | :button_6
  | :button_7
  | :button_8
  | :button_9
  | :button_10
  | :button_11
  | :button_12
  | :node_identify
  | :sound_1
  | :sound_2
  | :sound_3
  | :sound_4
  | :sound_5
  | :sound_6
  | :sound_7
  | :sound_8
  | :sound_9
  | :sound_10
  | :sound_11
  | :sound_12
  | :sound_13
  | :sound_14
  | :sound_15
  | :sound_16
  | :sound_17
  | :sound_18
  | :sound_19
  | :sound_20
  | :sound_21
  | :sound_22
  | :sound_23
  | :sound_24
  | :sound_25
  | :sound_26
  | :sound_27
  | :sound_28
  | :sound_29
  | :sound_30
  | :sound_31
  | :sound_32
  | :undefined

property_id()

@type property_id() ::
  byte()
  | :multilevel
  | :binary
  | :toggling_periods
  | :toggling_cycles
  | :toggling_on_time
  | :timeout_minutes
  | :timeout_seconds
  | :timeout_hundredths_second
  | :sound_level
  | :low_power
  | :undefined

resource()

@type resource() :: [
  indicator_id: indicator_id(),
  property_id: property_id(),
  value: byte()
]

value()

@type value() :: byte() | :on | :off | :restore

Functions

indicator_id_from_byte(byte)

indicator_id_to_byte(byte)

property_id_from_byte(byte)

property_id_to_byte(byte)

value_from_byte(byte, arg2)

value_to_byte(byte, arg2)