"MultiChannelAssociation" Command Class
The Multi Channel Association Command Class is used to manage associations to Multi Channel End Point destinations as well as to NodeID destinations.
Summary
Types
@type node_endpoint() :: [ node: Grizzly.ZWave.node_id(), bit_address: 0 | 1, endpoint: 1..127 ]
Functions
@spec decode_nodes_and_node_endpoints(binary()) :: {[Grizzly.ZWave.node_id()], [node_endpoint()]}
@spec encode_node_endpoints([node_endpoint()]) :: binary()