This command is used to unlock a node that is currently locked.
Params:
:magic_code- This field contains the Magic Code used to unlock the node.
Summary
Types
@type param() :: {:magic_code, String.t()}
This command is used to unlock a node that is currently locked.
Params:
:magic_code - This field contains the Magic Code used to unlock the node.@type param() :: {:magic_code, String.t()}