Grizzly.ZWave.Commands.AssociationGroupInfoReport (grizzly v0.15.4) View Source
This command is used to advertise the properties of one or more association groups.
Params:
:dynamic- whether the group info is subject to be changed by the device:groups_info- a list of group info
Link to this section Summary
Link to this section Types
Specs
Specs
param() :: {:groups_info, [group_info()]} | {:dynamic, boolean()}