The Multi Command Encapsulated Command used to contain multiple Commands.
Params:
:commands- the commands encapsulated in this one
Summary
Types
@type param() :: {:commands, [Grizzly.ZWave.Command.t()]}
The Multi Command Encapsulated Command used to contain multiple Commands.
Params:
:commands - the commands encapsulated in this one@type param() :: {:commands, [Grizzly.ZWave.Command.t()]}