Grizzly.ZWave.Commands.NetworkManagementMultiChannelEndPointGet
(grizzly v9.1.0)
Command is used to query the number of Multi Channel End Points and other relevant Multi Channel attributes
Params:
:seq_number- the sequence number for this command:node_id- the node id in question