Grizzly.ZWave.Commands.NodeAddKeysReport (grizzly v9.1.0)

Copy Markdown View Source

Command to report the security keys requested by an including node if that node is participating in S2 bootstrapping.

Params:

  • :seq_number - the sequence number of the command (required)
  • :csa - if the including node is doing client side authentication (require)
  • :requested_keys - a list of requested security keys see Grizzly.ZWave.Security for more information. (required)