Command used to grant the security keys to the including node if the including node requested keys.
This normally only needs to happen during the S2 bootstrapping process.
Params:
:seq_number- the sequence number (required):csa- if the including node requested client side authentication, then setting this totruewill allow for that node to preform CSA (required):granted_keys- the keys the including controller is granting to the including device, seeGrizzly.ZWave.Securityfor more information (required)