Z-Wave command for NODE_REMOVE_STATUS
This command is useful to respond to a Grizzly.ZWave.Commands.NodeRemove
command.
Params:
:seq_number- the sequence number from the original node remove command:status- the status of the result of the node removal:node_id- the node id of the removed node:command_class_version- explicitly set the command class version used to encode the command (optional - defaults to NetworkManagementInclusion v4)
When encoding the params you can encode for a specific command class version
by passing the :command_class_version to the encode options
Grizzly.ZWave.Commands.NodeRemoveStatus.encode_params(node_remove_status)If there is no command class version specified this will encode to version 4 of the
NetworkManagementInclusion command class. This version supports the use of 16 bit node
ids.