The Z/IP Packet keep alive command
Params:
:ack_flag- the flag if the receiving node should acknowledge the keep alive packet or not
Summary
Types
@type ack_flag() :: :ack_response | :ack_request
@type param() :: {:ack_flag, ack_flag()}
The Z/IP Packet keep alive command
Params:
:ack_flag - the flag if the receiving node should acknowledge the
keep alive packet or not@type ack_flag() :: :ack_response | :ack_request
@type param() :: {:ack_flag, ack_flag()}