Grizzly.ZWave.DeviceClasses (grizzly v9.1.0)

Copy Markdown View Source

Z-Wave device classes

Summary

Functions

Try to make a basic device class from a byte

Try to get the generic device class for the byte

Try to get the specific device class from the byte given the generic device class

Make a byte from a device class

Turn the generic device class into a byte

Make the specific device class into a byte

Types

basic_device_class()

@type basic_device_class() :: atom()

generic_device_class()

@type generic_device_class() :: atom()

specific_device_class()

@type specific_device_class() :: atom()

Functions

decode_basic(byte)

@spec decode_basic(byte()) :: basic_device_class() | :unknown

Try to make a basic device class from a byte

decode_generic(byte)

@spec decode_generic(byte()) :: generic_device_class() | :unknown

Try to get the generic device class for the byte

decode_specific(gen_class, byte)

@spec decode_specific(generic_device_class(), byte()) ::
  specific_device_class() | :unknown

Try to get the specific device class from the byte given the generic device class

encode_basic(device_class)

@spec encode_basic(basic_device_class()) :: byte()

Make a byte from a device class

encode_generic(device_class)

@spec encode_generic(generic_device_class()) :: byte()

Turn the generic device class into a byte

encode_specific(gen_class, spec_class)

@spec encode_specific(generic_device_class(), specific_device_class()) :: byte()

Make the specific device class into a byte