Encoding and decoding functions for notification events and types from the Notification command class.
Summary
Functions
Lists all events associated with the given notification type.
Lists all notification types.
Decode a notification event.
Encode a notification event.
Decode a notification type.
Encode a notification type.