Module for Z-Wave protocol specific functionality and information
Summary
Types
The volume at which a tone is played.
Types
@type endpoint_id() :: 0..127
@type node_id() :: non_neg_integer()
@type seq_number() :: non_neg_integer()
@type sound_switch_volume() :: 0..100 | 255
The volume at which a tone is played.
Values
0- Indicates an off/mute volume setting.1..100- Indicates the actual volume setting from 1% to 100%.255- Restore the most recent non-zero volume setting. This value MUST be ignored if the current volume is not zero. This value MAY be used to set the default tone without modifying the volume setting.
Functions
CRC-16/AUG-CCITT
@spec from_binary(binary()) :: {:ok, Grizzly.ZWave.Command.t()} | {:error, Grizzly.ZWave.DecodeError.t()}
@spec to_binary(Grizzly.ZWave.Command.t()) :: binary()