Grizzly.ZWave.CommandClasses.NetworkManagementInstallationMaintenance
(grizzly v9.1.0)
"NetworkManagementInstallationMaintenance" Command Class
The Network Management Installation and Maintenance Command Class is used to access statistical data.
Summary
Functions
Decodes the given byte to an 8-bit signed integer (or one of the special values defined in the spec).
Encodes the given RSSI value to an 8-bit signed integer.
Types
@type neighbor() :: [neighbor_param()]
@type route_type() ::
:no_route
| :last_working_route
| :next_to_last_working_route
| :set_by_application
@type rssi() ::
:rssi_not_available
| :rssi_max_power_saturated
| :rssi_below_sensitivity
| -124..127
@type speed() :: :"9.6kbit/s" | :"40kbit/s" | :"100kbit/s" | :reserved
@type speeds() :: [speed()]
@type statistic() :: {:route_changes, byte()} | {:transmission_count, byte()} | {:neighbors, [neighbor()]} | {:packet_error_count, byte()} | {:sum_of_transmission_times, non_neg_integer()} | {:sum_of_transmission_times_squared, non_neg_integer()}
@type statistics() :: [statistic()]
Functions
@spec route_type_from_byte(any()) :: {:error, Grizzly.ZWave.DecodeError.t()} | {:ok, route_type()}
@spec route_type_to_byte(route_type()) :: byte()
Decodes the given byte to an 8-bit signed integer (or one of the special values defined in the spec).
NOTE: In order to support Z/IP Gateway quirks, this function accepts values outside of the range specified in the spec (-32..-128). This function may return any value in the range -128..124.
Encodes the given RSSI value to an 8-bit signed integer.
NOTE: In order to support Z/IP Gateway quirks, this function accepts values outside of the range specified in the spec (-32..-128). Values out of range for an 8-bit signed integer will overflow.
@spec speed_from_byte(byte()) :: {:ok, speed()} | {:error, Grizzly.ZWave.DecodeError.t()}