Grizzly.ZWave.Commands.MultiChannelAggregatedMembersReport
(grizzly v9.1.0)
This command is used to advertise the members of an Aggregated End Point.
Params:
:aggregated_end_point- an aggregated end_point (required):members- the lists of end points member of the aggregated end point (required, can be an empty list)