Z-Wave device classes
Summary
Functions
Try to make a basic device class from a byte
Try to get the generic device class for the byte
Try to get the specific device class from the byte given the generic device class
Make a byte from a device class
Turn the generic device class into a byte
Make the specific device class into a byte
Types
Functions
@spec decode_basic(byte()) :: basic_device_class() | :unknown
Try to make a basic device class from a byte
@spec decode_generic(byte()) :: generic_device_class() | :unknown
Try to get the generic device class for the byte
@spec decode_specific(generic_device_class(), byte()) :: specific_device_class() | :unknown
Try to get the specific device class from the byte given the generic device class
@spec encode_basic(basic_device_class()) :: byte()
Make a byte from a device class
@spec encode_generic(generic_device_class()) :: byte()
Turn the generic device class into a byte
@spec encode_specific(generic_device_class(), specific_device_class()) :: byte()
Make the specific device class into a byte